TAG_MAP = { 
   'Ncmsn':{ 
      74:92,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmsg':{ 
      74:92,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmsd':{ 
      74:92,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmsan':{ 
      74:92,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmsay':{ 
      74:92,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmsv':{ 
      74:92,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmsl':{ 
      74:92,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmsi':{ 
      74:92,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Ncmpn':{ 
      74:92,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Ncmpg':{ 
      74:92,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Ncmpd':{ 
      74:92,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Ncmpa':{ 
      74:92,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Ncmpv':{ 
      74:92,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Ncmpl':{ 
      74:92,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Ncmpi':{ 
      74:92,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Ncfsn':{ 
      74:92,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Ncfsg':{ 
      74:92,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Ncfsd':{ 
      74:92,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Ncfsa':{ 
      74:92,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Ncfsv':{ 
      74:92,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Ncfsl':{ 
      74:92,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Ncfsi':{ 
      74:92,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Ncfpn':{ 
      74:92,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Ncfpg':{ 
      74:92,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Ncfpd':{ 
      74:92,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Ncfpa':{ 
      74:92,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Ncfpv':{ 
      74:92,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Ncfpl':{ 
      74:92,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Ncfpi':{ 
      74:92,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Ncnsn':{ 
      74:92,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Ncnsg':{ 
      74:92,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Ncnsd':{ 
      74:92,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Ncnsa':{ 
      74:92,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Ncnsv':{ 
      74:92,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Ncnsl':{ 
      74:92,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Ncnsi':{ 
      74:92,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Ncnpn':{ 
      74:92,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Ncnpg':{ 
      74:92,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Ncnpd':{ 
      74:92,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Ncnpa':{ 
      74:92,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Ncnpv':{ 
      74:92,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Ncnpl':{ 
      74:92,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Ncnpi':{ 
      74:92,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Np-pn':{ 
      74:96,
      'Case':'Nom',
      'Number':'Plur'
   },
   'Np-pg':{ 
      74:96,
      'Case':'Gen',
      'Number':'Plur'
   },
   'Npmsn':{ 
      74:96,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmsg':{ 
      74:96,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmsd':{ 
      74:96,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmsan':{ 
      74:96,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmsay':{ 
      74:96,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmsv':{ 
      74:96,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmsl':{ 
      74:96,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmsi':{ 
      74:96,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Npmpn':{ 
      74:96,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Npmpg':{ 
      74:96,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Npmpd':{ 
      74:96,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Npmpa':{ 
      74:96,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Npmpv':{ 
      74:96,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Npmpl':{ 
      74:96,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Npmpi':{ 
      74:96,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Npfsn':{ 
      74:96,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Npfsg':{ 
      74:96,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Npfsd':{ 
      74:96,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Npfsa':{ 
      74:96,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Npfsv':{ 
      74:96,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Npfsl':{ 
      74:96,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Npfsi':{ 
      74:96,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Npfpn':{ 
      74:96,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Npfpg':{ 
      74:96,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Npfpd':{ 
      74:96,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Npfpa':{ 
      74:96,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Npfpv':{ 
      74:96,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Npfpl':{ 
      74:96,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Npfpi':{ 
      74:96,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Npnsn':{ 
      74:96,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Npnsg':{ 
      74:96,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Npnsd':{ 
      74:96,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Npnsa':{ 
      74:96,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Npnsv':{ 
      74:96,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Npnsl':{ 
      74:96,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Npnsi':{ 
      74:96,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Npnpn':{ 
      74:96,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Npnpg':{ 
      74:96,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Npnpd':{ 
      74:96,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Npnpa':{ 
      74:96,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Npnpv':{ 
      74:96,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Npnpl':{ 
      74:96,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Npnpi':{ 
      74:96,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Vmn':{ 
      74:100,
      'VerbForm':'Inf'
   },
   'Vmp-sm':{ 
      74:100,
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Vmp-sf':{ 
      74:100,
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Vmp-sn':{ 
      74:100,
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Vmp-pm':{ 
      74:100,
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Vmp-pf':{ 
      74:100,
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Vmp-pn':{ 
      74:100,
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Vmr1s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmr1p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmr2s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmr2p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmr3s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmr3s-y':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmr3p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmr3p-y':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vmm1p':{ 
      74:100,
      'Mood':'Imp',
      'Number':'Plur',
      'Person':'One',
      'VerbForm':'Fin'
   },
   'Vmm2s':{ 
      74:100,
      'Mood':'Imp',
      'Number':'Sing',
      'Person':'Two',
      'VerbForm':'Fin'
   },
   'Vmm2p':{ 
      74:100,
      'Mood':'Imp',
      'Number':'Plur',
      'Person':'Two',
      'VerbForm':'Fin'
   },
   'Vma1s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Aor',
      'VerbForm':'Fin'
   },
   'Vma1p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Aor',
      'VerbForm':'Fin'
   },
   'Vma2s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Aor',
      'VerbForm':'Fin'
   },
   'Vma2p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Aor',
      'VerbForm':'Fin'
   },
   'Vma3s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Aor',
      'VerbForm':'Fin'
   },
   'Vma3p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Aor',
      'VerbForm':'Fin'
   },
   'Vme1s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vme1p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vme2s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vme2p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vme3s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vme3p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Van':{ 
      74:87,
      'VerbForm':'Inf'
   },
   'Vap-sm':{ 
      74:87,
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Vap-sf':{ 
      74:87,
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Vap-sn':{ 
      74:87,
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Vap-pm':{ 
      74:87,
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Vap-pf':{ 
      74:87,
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Vap-pn':{ 
      74:87,
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Var1s':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var1s-y':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var1p':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var1p-y':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var2s':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var2p':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var3s':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var3s-y':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var3p':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Var3p-y':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin'
   },
   'Vam1p':{ 
      74:87,
      'Mood':'Imp',
      'Number':'Plur',
      'Person':'One',
      'VerbForm':'Fin'
   },
   'Vam2s':{ 
      74:87,
      'Mood':'Imp',
      'Number':'Sing',
      'Person':'Two',
      'VerbForm':'Fin'
   },
   'Vam2p':{ 
      74:87,
      'Mood':'Imp',
      'Number':'Plur',
      'Person':'Two',
      'VerbForm':'Fin'
   },
   'Vaa1s':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Aor',
      'VerbForm':'Fin'
   },
   'Vae1s':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vae1p':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vae2s':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vae2p':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vae3s':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vae3p':{ 
      74:87,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Imp',
      'VerbForm':'Fin'
   },
   'Vcn':{ 
      74:100,
      'VerbForm':'Inf',
      'VerbType':'Cop'
   },
   'Vcp-sm':{ 
      74:100,
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part',
      'VerbType':'Cop'
   },
   'Vcp-sf':{ 
      74:100,
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part',
      'VerbType':'Cop'
   },
   'Vcp-sn':{ 
      74:100,
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part',
      'VerbType':'Cop'
   },
   'Vcp-pm':{ 
      74:100,
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part',
      'VerbType':'Cop'
   },
   'Vcp-pf':{ 
      74:100,
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part',
      'VerbType':'Cop'
   },
   'Vcp-pn':{ 
      74:100,
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part',
      'VerbType':'Cop'
   },
   'Vcr1s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr1s-y':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr1p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr1p-y':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr2s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr2p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr2p-y':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr3':{ 
      74:100,
      'Mood':'Ind',
      'Person':'Three',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr3s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr3s-y':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr3p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcr3p-y':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Polarity':'Neg',
      'Tense':'Pres',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcm1p':{ 
      74:100,
      'Mood':'Imp',
      'Number':'Plur',
      'Person':'One',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcm2s':{ 
      74:100,
      'Mood':'Imp',
      'Number':'Sing',
      'Person':'Two',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vcm2p':{ 
      74:100,
      'Mood':'Imp',
      'Number':'Plur',
      'Person':'Two',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vca1s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Aor',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vca1p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Aor',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vca2s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Aor',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vca2p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Aor',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vca3s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Aor',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vca3p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Aor',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vce1s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'One',
      'Tense':'Imp',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vce1p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'One',
      'Tense':'Imp',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vce2s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Two',
      'Tense':'Imp',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vce2p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Two',
      'Tense':'Imp',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vce3s':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Sing',
      'Person':'Three',
      'Tense':'Imp',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Vce3p':{ 
      74:100,
      'Mood':'Ind',
      'Number':'Plur',
      'Person':'Three',
      'Tense':'Imp',
      'VerbForm':'Fin',
      'VerbType':'Cop'
   },
   'Agpmsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsann':{ 
      74:84,
      'Animacy':'Inan',
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsany':{ 
      74:84,
      'Animacy':'Anim',
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsayn':{ 
      74:84,
      'Animacy':'Inan',
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsayy':{ 
      74:84,
      'Animacy':'Anim',
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agpmpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmply':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpmpiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agpfsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agpfpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfply':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpfpiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agpnsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agpnpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnply':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agpnpiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcmsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsayn':{ 
      74:84,
      'Animacy':'Inan',
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agcmpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmply':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcmpiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agcfsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agcfpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfply':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcfpiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agcnsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agcnpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agcnpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsmsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsayn':{ 
      74:84,
      'Animacy':'Inan',
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsayy':{ 
      74:84,
      'Animacy':'Anim',
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Sing'
   },
   'Agsmpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmply':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsmpiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur'
   },
   'Agsfsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing'
   },
   'Agsfpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsfpiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur'
   },
   'Agsnsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Sing'
   },
   'Agsnpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnply':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Agsnpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur'
   },
   'Aspmsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsann':{ 
      74:84,
      'Animacy':'Inan',
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspmpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspmpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspfpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspfpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes'
   },
   'Aspnpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Aspnpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes'
   },
   'Appmsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsann':{ 
      74:84,
      'Animacy':'Inan',
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsayn':{ 
      74:84,
      'Animacy':'Inan',
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsayy':{ 
      74:84,
      'Animacy':'Anim',
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appmpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appmpin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfsin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appfpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpdn':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpdy':{ 
      74:84,
      'Case':'Dat',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpay':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appfpin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnsn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsvy':{ 
      74:84,
      'Case':'Voc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnsin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Appnpn':{ 
      74:84,
      'Case':'Nom',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpnn':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpg':{ 
      74:84,
      'Case':'Gen',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpgn':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpd':{ 
      74:84,
      'Case':'Dat',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpa':{ 
      74:84,
      'Case':'Acc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpan':{ 
      74:84,
      'Case':'Acc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpv':{ 
      74:84,
      'Case':'Voc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpl':{ 
      74:84,
      'Case':'Loc',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpln':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpi':{ 
      74:84,
      'Case':'Ins',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Appnpin':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Ind',
      'Degree':'Pos',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Apcmsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Masc',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Apcfsny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Apcnsly':{ 
      74:84,
      'Case':'Loc',
      'Definite':'Def',
      'Degree':'Cmp',
      'Gender':'Neut',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Apsmpny':{ 
      74:84,
      'Case':'Nom',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Apsmpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Masc',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Apsfsgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Apsfsiy':{ 
      74:84,
      'Case':'Ins',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Sing',
      'VerbForm':'Part'
   },
   'Apsfpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Fem',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Apsnpgy':{ 
      74:84,
      'Case':'Gen',
      'Definite':'Def',
      'Degree':'Sup',
      'Gender':'Neut',
      'Number':'Plur',
      'VerbForm':'Part'
   },
   'Pp1-sn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-sg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-sg--y-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp1-sd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-sd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp1-sa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-sa--y-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp1-sl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-si--n-n':{ 
      74:95,
      'Case':'Ins',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-si--y-n':{ 
      74:95,
      'Case':'Ins',
      'Number':'Sing',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp1-pn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-pg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-pd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-pd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp1-pa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-pv--n-n':{ 
      74:95,
      'Case':'Voc',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-pl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp1-pi--n-n':{ 
      74:95,
      'Case':'Ins',
      'Number':'Plur',
      'Person':'One',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-sn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-sg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-sg--y-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp2-sd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-sd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp2-sa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-sa--y-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp2-sv--n-n':{ 
      74:95,
      'Case':'Voc',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-sl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-si--n-n':{ 
      74:95,
      'Case':'Ins',
      'Number':'Sing',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-pn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-pg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-pd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-pd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp2-pa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-pv--n-n':{ 
      74:95,
      'Case':'Voc',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-pl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp2-pi--n-n':{ 
      74:95,
      'Case':'Ins',
      'Number':'Plur',
      'Person':'Two',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3-pg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3-pg--y-n':{ 
      74:95,
      'Case':'Gen',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3-pd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3-pd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3-pa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3-pa--y-n':{ 
      74:95,
      'Case':'Acc',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3-pl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3-pi--n-n':{ 
      74:95,
      'Case':'Ins',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3msn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3msg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3msg--y-n':{ 
      74:95,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3msd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3msd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3msa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3msa--y-n':{ 
      74:95,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3msl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3msl--y-n':{ 
      74:95,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3msi--n-n':{ 
      74:95,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3msi--y-n':{ 
      74:95,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3mpn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3fsn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3fsg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3fsg--y-n':{ 
      74:95,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3fsd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3fsd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3fsa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3fsa--y-n':{ 
      74:95,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3fsl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3fsi--n-n':{ 
      74:95,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3fsi--y-n':{ 
      74:95,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3fpn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3nsn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3nsg--n-n':{ 
      74:95,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3nsg--y-n':{ 
      74:95,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3nsd--n-n':{ 
      74:95,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3nsd--y-n':{ 
      74:95,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3nsa--n-n':{ 
      74:95,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3nsa--y-n':{ 
      74:95,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3nsl--n-n':{ 
      74:95,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3nsl--y-n':{ 
      74:95,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3nsi--n-n':{ 
      74:95,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pp3nsi--y-n':{ 
      74:95,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Short'
   },
   'Pp3npn--n-n':{ 
      74:95,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'Person':'Three',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pd-msn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-msg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-msd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-msa--n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-msa--n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-msv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-msl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-msi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpn':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-mpi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fsn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fsg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fsd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fsa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fsv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fsl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fsi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fpn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fpg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fpd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fpa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fpv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fpl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-fpi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-nsn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-nsg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-nsd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-nsa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-nsv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-nsl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-nsi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-npn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-npg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-npd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-npa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-npv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-npl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pd-npi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Dem',
      'Variant':'Long'
   },
   'Pi-msn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msa--n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msa--n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-msi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpn':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-mpi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsv':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsl':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fsi':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpn':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsa----a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind'
   },
   'Pi-nsa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpg':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpd':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpv':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpl':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-fpi':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsn':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsg':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsd':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsv':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsl':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-nsi':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npn':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npg':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npd':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npv':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npl':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi-npi':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3m-n--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Nom',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3m-g--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Gen',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3m-d--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Dat',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3m-a--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3m-l--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Loc',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3m-i--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Ins',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3n-n--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Nom',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3n-g--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Gen',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3n-d--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Dat',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3n-a--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3n-l--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Loc',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3n-i--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Ins',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Long'
   },
   'Pi3n-i--y-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Ins',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Ind',
      'Variant':'Short'
   },
   'Pi3nsn----a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Person':'Three',
      'PronType':'Ind'
   },
   'Ps1msns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msas-n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msas-n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msap-n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msap-n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1msip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1mpip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fsip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1fpip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nsip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1nplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps1npip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'One',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msas-n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msas-n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msap-n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msap-n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2msip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2mpip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fsip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2fpip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nsip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npns-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npgs-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npds-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npas-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npvs-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npvp-n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npls-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2nplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npis-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps2npip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Two',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msnsmn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msnsfn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msnsnn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msgsmn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msgsfn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msgsnn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msdsmn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msdsfn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msdsnn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msasmn-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msasmn-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msasfn-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msasfn-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msasnn-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msasnn-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msap-n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msap-n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mslsmn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mslsfn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mslsnn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msismn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msisfn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msisnn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3msip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpnsmn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpnsfn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpnsnn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpgsmn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpgsfn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpgsnn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpdsmn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpdsfn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpdsnn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpasmn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpasfn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpasnn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mplsmn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mplsfn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mplsnn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpismn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpisfn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpisnn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3mpip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsnsmn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsnsfn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsnsnn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsgsmn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsgsfn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsgsnn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsdsmn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsdsfn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsdsnn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsasmn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsasfn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsasnn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fslsmn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fslsfn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fslsnn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsismn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsisfn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsisnn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fsip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpnsmn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpnsfn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpnsnn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpgsmn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpgsfn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpgsnn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpdsmn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpdsfn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpdsnn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpasmn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpasfn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpasnn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fplsmn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fplsfn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fplsnn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpismn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpisfn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpisnn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3fpip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsnsmn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsnsfn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsnsnn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsgsmn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsgsfn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsgsnn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsdsmn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsdsfn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsdsnn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsasmn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsasfn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsasnn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nslsmn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nslsfn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nslsnn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nslp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsismn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsisfn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsisnn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Sing',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nsip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npnsmn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npnsfn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npnsnn-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npnp-n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npgsmn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npgsfn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npgsnn-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npgp-n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npdsmn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npdsfn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npdsnn-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npdp-n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npasmn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npasfn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npasnn-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npap-n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nplsmn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nplsfn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nplsnn-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3nplp-n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npismn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Gender[psor]':'Masc',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npisfn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Gender[psor]':'Fem',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npisnn-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Gender[psor]':'Neut',
      'Number':'Plur',
      'Number[psor]':'Sing',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Ps3npip-n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'Number[psor]':'Plur',
      'Person':'Three',
      'Poss':'Yes',
      'PronType':'Prs',
      'Variant':'Long'
   },
   'Pq-msn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-msg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-msd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-msa--n-an':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-msa--n-ay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-msv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-msl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-msi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-mpn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-mpg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-mpd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-mpa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-mpv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-mpl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-mpi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fsn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fsg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fsd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fsa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fsv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fsl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fsi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fpn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fpg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fpd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fpa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fpv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fpl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-fpi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-nsn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-nsg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-nsd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-nsa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-nsv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-nsl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-nsi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-npn--n-a':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-npg--n-a':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-npd--n-a':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-npa--n-a':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-npv--n-a':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-npl--n-a':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq-npi--n-a':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3m-n--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Nom',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3m-g--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Gen',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3m-g--y-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Gen',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3m-d--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Dat',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3m-d--y-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Dat',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3m-a--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3m-a--y-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3m-l--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Loc',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3m-l--y-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Loc',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3m-i--n-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Ins',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3m-i--y-ny':{ 
      74:95,
      'Animacy':'Anim',
      'Case':'Ins',
      'Gender':'Masc',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3n-n--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Nom',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3n-g--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Gen',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3n-g--y-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Gen',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3n-d--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Dat',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3n-d--y-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Dat',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3n-a--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3n-l--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Loc',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3n-l--y-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Loc',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Pq3n-i--n-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Ins',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Long'
   },
   'Pq3n-i--y-nn':{ 
      74:95,
      'Animacy':'Inan',
      'Case':'Ins',
      'Gender':'Neut',
      'Person':'Three',
      'PronType':'Int',
      'Variant':'Short'
   },
   'Px--sg--npn':{ 
      74:95,
      'Case':'Gen',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px--sg--ypn':{ 
      74:95,
      'Case':'Gen',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Short'
   },
   'Px--sd--npn':{ 
      74:95,
      'Case':'Dat',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px--sd--ypn':{ 
      74:95,
      'Case':'Dat',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Short'
   },
   'Px--sa--npn':{ 
      74:95,
      'Case':'Acc',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px--sa--ypn':{ 
      74:95,
      'Case':'Acc',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Short'
   },
   'Px--sl--npn':{ 
      74:95,
      'Case':'Loc',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px--si--npn':{ 
      74:95,
      'Case':'Ins',
      'Number':'Sing',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msn--nsa':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msg--nsa':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msd--nsa':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msa--nsan':{ 
      74:90,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msa--nsay':{ 
      74:90,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msv--nsa':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msl--nsa':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-msi--nsa':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-mpn--nsa':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-mpg--nsa':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-mpd--nsa':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-mpa--nsa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-mpv--nsa':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-mpl--nsa':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-mpi--nsa':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fsn--nsa':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fsg--nsa':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fsd--nsa':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fsa--nsa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fsv--nsa':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fsl--nsa':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fsi--nsa':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fpn--nsa':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fpg--nsa':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fpd--nsa':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fpa--nsa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fpv--nsa':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fpl--nsa':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-fpi--nsa':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-nsn--nsa':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-nsg--nsa':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-nsd--nsa':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-nsa--nsa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-nsv--nsa':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-nsl--nsa':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-nsi--nsa':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Sing',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-npn--nsa':{ 
      74:90,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-npg--nsa':{ 
      74:90,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-npd--nsa':{ 
      74:90,
      'Case':'Dat',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-npa--nsa':{ 
      74:90,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-npv--nsa':{ 
      74:90,
      'Case':'Voc',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-npl--nsa':{ 
      74:90,
      'Case':'Loc',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Px-npi--nsa':{ 
      74:90,
      'Case':'Ins',
      'Gender':'Neut',
      'Number':'Plur',
      'Poss':'Yes',
      'PronType':'Prs',
      'Reflex':'Yes',
      'Variant':'Long'
   },
   'Rgp':{ 
      74:86,
      'Degree':'Pos'
   },
   'Rgc':{ 
      74:86,
      'Degree':'Cmp'
   },
   'Rgs':{ 
      74:86,
      'Degree':'Sup'
   },
   'Rr':{ 
      74:86,
      'VerbForm':'Conv'
   },
   'Sg':{ 
      74:85,
      'AdpType':'Prep',
      'Case':'Gen'
   },
   'Sd':{ 
      74:85,
      'AdpType':'Prep',
      'Case':'Dat'
   },
   'Sa':{ 
      74:85,
      'AdpType':'Prep',
      'Case':'Acc'
   },
   'Sl':{ 
      74:85,
      'AdpType':'Prep',
      'Case':'Loc'
   },
   'Si':{ 
      74:85,
      'AdpType':'Prep',
      'Case':'Ins'
   },
   'Cc':{ 
      74:89
   },
   'Cs':{ 
      74:98
   },
   'Md':{ 
      74:93,
      'NumForm':'Digit'
   },
   'Mdo':{ 
      74:93,
      'NumForm':'Digit'
   },
   'Mdc':{ 
      74:93,
      'NumForm':'Digit'
   },
   'Mro-p':{ 
      74:84,
      'Number':'Plur',
      'NumForm':'Roman',
      'NumType':'Ord'
   },
   'Mlc-s':{ 
      74:93,
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlc-p':{ 
      74:93,
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlc-pn':{ 
      74:93,
      'Case':'Nom',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlc-pg':{ 
      74:93,
      'Case':'Gen',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlc-pd':{ 
      74:93,
      'Case':'Dat',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlc-pa':{ 
      74:93,
      'Case':'Acc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmsn':{ 
      74:93,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmsg':{ 
      74:93,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmsd':{ 
      74:93,
      'Case':'Dat',
      'Gender':'Masc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmsan':{ 
      74:93,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmsay':{ 
      74:93,
      'Animacy':'Anim',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmsl':{ 
      74:93,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmsi':{ 
      74:93,
      'Case':'Ins',
      'Gender':'Masc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmpn':{ 
      74:93,
      'Case':'Nom',
      'Gender':'Masc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmpg':{ 
      74:93,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmpa':{ 
      74:93,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmpan':{ 
      74:93,
      'Animacy':'Inan',
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcmpl':{ 
      74:93,
      'Case':'Loc',
      'Gender':'Masc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfs':{ 
      74:93,
      'Gender':'Fem',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfsn':{ 
      74:93,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfsg':{ 
      74:93,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfsd':{ 
      74:93,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfsa':{ 
      74:93,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfsl':{ 
      74:93,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfsi':{ 
      74:93,
      'Case':'Ins',
      'Gender':'Fem',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfp':{ 
      74:93,
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfpn':{ 
      74:93,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfpg':{ 
      74:93,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcfpa':{ 
      74:93,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcnsn':{ 
      74:93,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcnsg':{ 
      74:93,
      'Case':'Gen',
      'Gender':'Neut',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcnsa':{ 
      74:93,
      'Case':'Acc',
      'Gender':'Neut',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mlcnpn':{ 
      74:93,
      'Case':'Nom',
      'Gender':'Neut',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Card'
   },
   'Mls-s':{ 
      74:84,
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mls-sa':{ 
      74:84,
      'Case':'Acc',
      'Number':'Sing',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mls-p':{ 
      74:84,
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mls-pn':{ 
      74:84,
      'Case':'Nom',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsmpg':{ 
      74:84,
      'Case':'Gen',
      'Gender':'Masc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsmpa':{ 
      74:84,
      'Case':'Acc',
      'Gender':'Masc',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsfp':{ 
      74:84,
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsfpn':{ 
      74:84,
      'Case':'Nom',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsfpg':{ 
      74:84,
      'Case':'Gen',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsfpd':{ 
      74:84,
      'Case':'Dat',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsfpa':{ 
      74:84,
      'Case':'Acc',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Mlsfpl':{ 
      74:84,
      'Case':'Loc',
      'Gender':'Fem',
      'Number':'Plur',
      'NumForm':'Word',
      'NumType':'Sets'
   },
   'Qz':{ 
      74:94,
      'Polarity':'Neg'
   },
   'Qq':{ 
      74:94,
      'PronType':'Int'
   },
   'Qo':{ 
      74:94,
      'PartType':'Mod'
   },
   'Qr':{ 
      74:94,
      'Polarity':'Pos'
   },
   'I':{ 
      74:91
   },
   'Y':{ 
      74:101,
      'Abbr':'Yes'
   },
   'X':{ 
      74:101
   },
   'Xf':{ 
      74:101,
      'Foreign':'Yes'
   },
   'Px--sa':{ 
      74:95,
      'Case':'Acc',
      'Number':'Sing',
      'PronType':'Prs'
   },
   'Z':{ 
      74:97
   }
}